@@ -16,7 +16,7 @@ from datetime import datetime
 
 
 # Current version number
-__version__ = "0.3.3"
+__version__ = "0.3.4"
 
 
 # Some constants
@@ -254,7 +254,7 @@ def main() -> None:
         print("  run again without --dry-run to execute\n")
 
     # check srcdir
-    srcdir = resolve_path(args.srcdir)
+    srcdir = args.srcdir = resolve_path(args.srcdir)
     if not os.path.isdir(srcdir):
         print(f"Source directory {srcdir} not found! Please select a valid source.")
         quit()
@@ -354,12 +354,7 @@ def main() -> None:
         outdir = os.path.dirname(
             os.path.join(outdir, srcdir[len(project_root) + len(os.sep) :])
         )
-    if outdir == srcdir:
-        print("source and output directories can not be the same")
-        print(f"  currently using {srcdir} for both")
-        quit()
-    else:
-        settings["output dir"] = outdir
+    settings["output dir"] = outdir
 
     #  run jml
     logger.info("compiling source project <{}>".format(settings["name"]))
@@ -412,6 +407,11 @@ def create_version(version: int, settings: configparser.SectionProxy) -> t.Set[i
         )
     outdir = os.path.join(outdir, ver_name)
 
+    if srcdir == outdir:
+        logger.warning(f"skipped {ver_name} (version {version})")
+        logger.warning(f"  output path would override source folder at {srcdir}")
+        return set()
+
     # prepare output folders
     if os.path.isdir(outdir):
         if settings.getboolean("clear"):
@@ -441,7 +441,7 @@ def create_version(version: int, settings: configparser.SectionProxy) -> t.Set[i
     strippos = len(srcdir) + 1
 
     # compile files in the srcdir
-    logger.info(f"  creating version {ver_name} in {outdir}")
+    print(f"  creating version {ver_name} in {outdir}")
     for root, dirs, files in os.walk(srcdir):
         subpath = root[strippos:]
         outroot = os.path.join(outdir, subpath)
@@ -551,12 +551,16 @@ def create_zip(path: str, settings: configparser.SectionProxy) -> None:
 
         # create zip file
         if not DRY_RUN:
-            with zipfile.ZipFile(outfile, "w", zipfile.ZIP_DEFLATED) as zipf:
-                for root, dirs, files in os.walk(path):
-                    for file in files:
-                        filepath = os.path.join(root, file)
-                        relpath = os.path.relpath(filepath, start=path)
-                        zipf.write(filepath, arcname=relpath)
+            try:
+                with zipfile.ZipFile(outfile, "w", zipfile.ZIP_DEFLATED) as zipf:
+                    for root, dirs, files in os.walk(path):
+                        for file in files:
+                            filepath = os.path.join(root, file)
+                            relpath = os.path.relpath(filepath, start=path)
+                            zipf.write(filepath, arcname=relpath)
+            except OSError as oserr:
+                logger.warning(f"  could not create zip at {outfile} ({oserr.strerror})")
+                return
         logger.info(f"  created zip file at {outfile}")
 
 
@@ -677,15 +681,6 @@ def args_to_config(
                     config[k] = str(v)
 
 
-def open_file(path: str, mode: str = "w", encoding: str = "utf-8") -> t.IO[t.Any]:
-    """Opens a file for reading/writing.
-    """
-    if mode[0] == "w" and DRY_RUN:
-        return io.StringIO()
-    else:
-        return open(path, mode, encoding=encoding)
-
-
 def create_transform(version: int, settings: configparser.SectionProxy) -> t.Callable:
     transform = lambda line: line  # noqa: E731
 
@@ -756,19 +751,54 @@ def test_version(version1: t.Union[str, int], version2: t.Union[str, int]) -> bo
 
 # Utilities for file operations
 ## just wrappers that respect DRY_RUN settings
+def open_file(path: str, mode: str = "w", encoding: str = "utf-8") -> t.IO[t.Any]:
+    """Opens a file for reading/writing.
+    """
+    if mode[0] == "w" and DRY_RUN:
+        return io.StringIO()
+    else:
+        try:
+            return open(path, mode, encoding=encoding)
+        except OSError as oserr:
+            abort("could not open file", err=oserr)
+            quit()
+
+
 def copy_file(inpath: str, outpath: str) -> None:
     if not DRY_RUN:
-        shutil.copy(inpath, outpath)
+        try:
+            shutil.copy(inpath, outpath)
+        except OSError as oserr:
+            abort("could not copy file", err=oserr)
 
 
 def remove_dir(inpath: str) -> None:
     if not DRY_RUN:
-        shutil.rmtree(inpath)
+        try:
+            shutil.rmtree(inpath)
+        except OSError as oserr:
+            abort(f"could not remove directory {inpath}", err=oserr)
 
 
 def make_dirs(path: str, exist_ok: bool = True) -> None:
     if not DRY_RUN:
-        os.makedirs(path, exist_ok=exist_ok)
+        try:
+            os.makedirs(path, exist_ok=exist_ok)
+        except OSError as oserr:
+            abort("could not create directory", err=oserr)
+
+
+def abort(message: str = "", err: OSError = None) -> None:
+    """Shows an optional error message, shuts everything down and
+    aborts the script with error code 1.
+    """
+    if message:
+        logger.error(message)
+    if err:
+        logger.error(f"  ({err.errno}) {err.filename}: {err.strerror}")
+    logging.shutdown()
+    print("-- operation aborted --")
+    quit(1)
 
 
 # When run as a single file outside module structure
